@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: export_htmlcss.c,v 1.2 2005/10/29 18:26:19 avian Exp $ */
+/* $Id: export_htmlcss.c,v 1.4 2006-04-26 13:58:40 avian Exp $ */
 
 #include <stdio.h>
 #include <time.h>
@@ -63,7 +63,7 @@ char *get_dayname(int n) {
 		t.tm_wday=n%5+1;
 		strftime(buff, BUFFSIZE, "%a", &t);
 
-		if(((int) cd)==-1) {
+		if(cd==((iconv_t)(-1))) {
 			return(buff);
 		}
 
@@ -198,7 +198,7 @@ void make_css()
 	fprintf(out, "}\n");
 }
 
-void make_index(char *type, char *desc)
+void make_index(char *type, const char *desc)
 {
 	int resid;
 	resourcetype *restype;
@@ -457,7 +457,9 @@ int export_function(table *tab, moduleoption *opt, char *file)
 		namedays=1;
 	}
 
+	#if ENABLE_NLS	
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
+	#endif
 
 	fprintf(out, "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" " 
 			"\"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n");
@@ -506,7 +508,10 @@ int export_function(table *tab, moduleoption *opt, char *file)
 	fprintf(out, "</p>\n");
 
         fprintf(out, "</body>\n</html>\n");
+
+	#if ENABLE_NLS
 	bind_textdomain_codeset(PACKAGE, "");
+	#endif
 
 	if(out!=stdout) fclose(out);
 
