@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: freeperiod.c,v 1.3 2006-01-27 19:25:15 avian Exp $ */
+/* $Id: freeperiod.c,v 1.4 2006-06-15 17:47:28 avian Exp $ */
 
 /** @module
  *
@@ -188,25 +188,28 @@ int getfreeday(char *restriction, char *cont, resource *res1)
 
 int module_precalc(moduleoption *opt) 
 {
+	int i;
+	int timeid, teachid;
+	tupleinfo *tup;
+	domain *dom;
+	struct tlist *tnext;
+
 	if ( exclnum == 0 && texcl == NULL )
 	{
 		info(_("module '%s' has been loaded, but not used"), "freeperiod.so");
 		return 0;
 	}
 	
-	int i;
-	int timeid, teachid;
 	timeid = restype_find( "time" )->typeid; 
 	teachid = restype_find( "teacher" )->typeid;
-	tupleinfo *tup = dat_tuplemap;
-	domain *dom;
+	tup = dat_tuplemap;
 	for ( i = 0; i < dat_tuplenum; i++ )
 	{
+		struct tlist *tt;
 		dom = tup[i].dom[timeid];
 		if(excl!=NULL) {
 			domain_del( dom, excl, exclnum );
 		}
-		struct tlist *tt;
 		if ( ( tt = find_texcl( dat_tuplemap[i].resid[teachid] ) ) )
 			domain_del( dom, tt->frees, tt->freenum );
 	}
@@ -215,7 +218,6 @@ int module_precalc(moduleoption *opt)
 		free(excl);
 	}
 	
-	struct tlist *tnext;
 	while(texcl!=NULL) {
 		tnext=texcl->next;
 		free( texcl->frees );
@@ -228,11 +230,11 @@ int module_precalc(moduleoption *opt)
 
 int module_init(moduleoption *opt) 
 {
-	precalc_new(module_precalc);
-
 	int d,p;
 	moduleoption *result;
 
+	precalc_new(module_precalc);
+
 	texcl = NULL;
 	excl = NULL;
 	exclnum = 0;
