@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: preferredroom.c,v 1.2 2005/10/29 18:26:20 avian Exp $ */
+/* $Id: preferredroom.c,v 1.4 2007-06-06 18:16:57 avian Exp $ */
 
 /** @module
  *
@@ -169,6 +169,8 @@ int module_precalc(moduleoption *opt)
 
 		if((unused=(c==restype_find("class")->resnum))) {
 			for(c=0;c<dat_tuplenum&&peroom[c]==-1;c++);
+
+			unused=(c==dat_tuplenum);
 		}
 	}	
 	if ( unused ) {
@@ -182,6 +184,8 @@ int module_precalc(moduleoption *opt)
 int module_init(moduleoption *opt) 
 {
 	int c;
+	fitnessfunc *fitness;
+
 	ptroom=malloc(sizeof(*ptroom)*restype_find("teacher")->resnum);
 	for(c=0;c<restype_find("teacher")->resnum;c++) ptroom[c]=-1;
 
@@ -197,15 +201,13 @@ int module_init(moduleoption *opt)
 		return(-1);
 	}
 	
-	fitnessfunc *fitness;
-
 	precalc_new(module_precalc);
 
 	handler_res_new("teacher", "preferred-room", gettroom);
 	handler_res_new("class", "preferred-room", getcroom);
 	handler_tup_new("preferred-room", geteroom);
 
-	fitness=fitness_new("teacher preferred", 
+	fitness=fitness_new("preferred-room", 
 			option_int(opt, "weight"), 
 			option_int(opt, "mandatory"), 
 			module_fitness);
