@@ -15,16 +15,21 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: sametime.c,v 1.11 2006-03-27 15:24:11 avian Exp $ */
+/* $Id: sametime.c,v 1.15 2007-06-27 14:08:20 avian Exp $ */
 
 /** @module
  *
  * @author Tomaz Solc 
- * @author-email tomaz.solc@siol.net
+ * @author-email tomaz.solc@tablix.org
  *
  * @brief Adds a weight whenever a teacher or a class is required to be in two 
  * rooms at the same time.
  *
+ * Please note that this module will not consider it as an error if a teacher or
+ * a class has two events scheduled at the same time in the same room. This
+ * means that in 99% of cases you need to use this module together with
+ * timeplace.so to get the expected results.
+ *
  * @ingroup School scheduling, Multiweek scheduling
  */
 
@@ -159,9 +164,14 @@ int module_fitness(chromo **c, ext **e, slist **s)
 	return(sum);
 }
 
-int module_precalc(moduleoption *opt)
+/** @brief Checks if a constant resource type has too many events for the
+ * number of time slots.
+ *
+ * @param restype Resource type to check.
+ * @return 0 if there are enough timeslots defined and -1 otherwise. */
+static int check_time(resourcetype *restype)
 {
-	resourcetype *class, *teacher, *time;
+	resourcetype *time;
 	int n,m;
 	int result;
 
@@ -169,71 +179,67 @@ int module_precalc(moduleoption *opt)
 	int max;
 	int resid;
 
-	class=restype_find("class");
-	teacher=restype_find("teacher");
-	time=restype_find("time");
+	assert(!restype->var);
 
-	if(recursive) debug("Recursive conflicts were enabled");
+	time=restype_find("time");
 
 	result=0;
 
-	eventnum=malloc(sizeof(*eventnum)*teacher->resnum);
-	for(m=0;m<teacher->resnum;m++) eventnum[m]=0;
+	eventnum=malloc(sizeof(*eventnum)*restype->resnum);
+	for(m=0;m<restype->resnum;m++) eventnum[m]=0;
 
 	for(m=0;m<dat_tuplenum;m++) {
-		resid=dat_tuplemap[m].resid[teacher->typeid];
+		resid=dat_tuplemap[m].resid[restype->typeid];
+		assert(resid>=0);
 		eventnum[resid]++;
 	}
 
-	for(m=0;m<teacher->resnum;m++) {
+	for(m=0;m<restype->resnum;m++) {
 		max=0;
-		for(n=0;n<teacher->resnum;n++) {
-			if(res_get_conflict(teacher, m, n)&&n!=m) {
+		for(n=0;n<restype->resnum;n++) {
+			if(res_get_conflict(restype, m, n)&&n!=m) {
 				if(eventnum[n]>max) max=eventnum[n];
 			}
 		}
 		max=max+eventnum[m];
 
 		if(max>time->resnum) {
-			error(_("Too many events for teacher '%s'"), 
-							teacher->res[m].name);
+			error(_("Too many events for %s '%s'"),
+							restype->type,
+							restype->res[m].name);
 			error(_("%d events with only %d available time slots"), 
 							max, time->resnum);
 			result=-1;
+		} else {
+			debug("sametime: %s '%s' has %d events", restype->type,
+                                                      	restype->res[m].name,
+                                                      	max);
 		}
 	}
 
 	free(eventnum);
 
-	eventnum=malloc(sizeof(*eventnum)*class->resnum);
-	for(m=0;m<class->resnum;m++) eventnum[m]=0;
+	return(result);
+}
 
-	for(m=0;m<dat_tuplenum;m++) {
-		resid=dat_tuplemap[m].resid[class->typeid];
-		eventnum[resid]++;
+int module_precalc(moduleoption *opt)
+{
+	resourcetype *class, *teacher;
+
+	class=restype_find("class");
+	teacher=restype_find("teacher");
+
+	if(recursive) debug("Recursive conflicts were enabled");
+
+	if(!class->var) {
+		if(check_time(class)) return -1;
 	}
 
-	for(m=0;m<class->resnum;m++) {
-		max=0;
-		for(n=0;n<class->resnum;n++) {
-			if(res_get_conflict(class, m, n)&&n!=m) {
-				if(eventnum[n]>max) max=eventnum[n];
-			}
-		}
-		max=max+eventnum[m];
-
-		if(max>time->resnum) {
-			error(_("Too many events for class '%s'"), 
-							class->res[m].name);
-			error(_("%d events with only %d available time slots"), 
-							max, time->resnum);
-			result=-1;
-		}
+	if(!teacher->var) {
+		if(check_time(teacher)) return -1;
 	}
 
-	free(eventnum);
-
-	return result;
+	return 0;
 }
 
 int module_init(moduleoption *opt) 
