@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: genetic.c,v 1.5 2006-02-04 14:16:12 avian Exp $ */
+/* $Id: genetic.c,v 1.6 2006-04-22 19:24:04 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -265,10 +265,10 @@ void new_generation(population *pop)
 
         for(n=0;n<size;n++) {
        		if(tables[n]->fitness==FITNESS_UNDEF_IN_CACHE) {
-			updater_call(tables[n]);
+			updater_call_all(tables[n]);
 			cache_table_fitness(tables[n]);
 		} else if(tables[n]->fitness==FITNESS_UNDEF) {
-			updater_call(tables[n]);
+			updater_call_all(tables[n]);
 			table_fitness(tables[n]);
 		}
 	}
