@@ -1,5 +1,5 @@
-/* TABLIX, PGA general timetable solver                              */
-/* Copyright (C) 2002-2004 Tomaz Solc                                      */
+/* TABLIX, PGA general timetable solver                                    */
+/* Copyright (C) 2002-2006 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of the GNU General Public License as published by    */
@@ -15,13 +15,22 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: genetic.h,v 1.1.2.8 2005/09/02 19:30:42 avian Exp $ */
+/* $Id: genetic.h,v 1.4 2006-02-04 14:16:12 avian Exp $ */
 
 #ifndef _GENETIC_H
 #define _GENETIC_H
 
 #include "chromo.h"
 
+/** @brief Special fitness value meaning that the timetable needs to be 
+ * re-evaluated by the genetic algorithm. */
+#define FITNESS_UNDEF 		-1
+
+/** @brief Special fitness value meaning that the timetable needs to be 
+ * re-evaluated by the genetic algorithm and that the result is likely already
+ * stored in the fitness cache. */
+#define FITNESS_UNDEF_IN_CACHE 	-2
+
 extern int sibling;
 
 void new_generation(population *pop);
