@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: main.c,v 1.74 2006-05-14 10:27:06 avian Exp $ */
+/* $Id: main.c,v 1.76 2007-03-14 18:45:08 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -436,7 +436,7 @@ int main(int argc, char *argv[])
 
 	verbosity=102;
 
-        while ((c=getopt(argc, argv, "o:rd:t:p:"))!=-1) {
+        while ((c=getopt(argc, argv, "o:rd:t:p:i:n:"))!=-1) {
                 switch (c) {
 			#ifndef HAVE_LIBPVM3
                         case 'o': prefix=strdup(optarg);
@@ -449,9 +449,16 @@ int main(int argc, char *argv[])
 			case 'd': sscanf(optarg, "%d", &verbosity);
 				  verbosity+=100;
 				  break;
+			case 'i': mod_modulepath=optarg;
+				  break;
 			case 'p': if(par_get(optarg)) {
 					fatal(_("Parameter syntax error"));
 				  }
+				  break;
+			case 'n':
+				  /* This option is parsed by the master
+				   * process. */
+				  break;
                 }
         }
         if (!(optind<argc)) fatal(_("Wrong arguments"));
