@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: master.c,v 1.56 2006-05-14 10:00:15 avian Exp $ */
+/* $Id: master.c,v 1.58 2006-08-29 14:32:24 avian Exp $ */
 
 /* This whole thing needs to be cleaned up and documented. Any volunteers? */
 
@@ -83,7 +83,7 @@ along with this program; if not, write to the Free Software\n\
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA\n"));
         printf("\n");
 
-        printf("$Id: master.c,v 1.56 2006-05-14 10:00:15 avian Exp $\n");
+        printf("$Id: master.c,v 1.58 2006-08-29 14:32:24 avian Exp $\n");
         printf(_("Compile time options:\n"));
         #ifdef HAVE_LIBPVM3
         printf(_("\tParallel genetic algorithm (using PVM3)\n"));
@@ -118,18 +118,28 @@ void print_syntax()
   -r                    restore saved populations\n\
   -h                    display this help\n\
   -v                    display version, compile time options and\n\
-                        copyright information\n\
+                        copyright information\n"));
+
+	#ifdef HAVE_LIBPVM3
+	printf(_("\
   -l NODES              set number of computing nodes that are allowed to\n\
                         simultaneously perform local search (set to -1 for \n\
-                        no limit or 0 to disable local search. Default 1)\n\
+                        no limit or 0 to disable local search. Default 1)\n"));
+	#endif
+
+	printf(_("\
   -d LEVEL              verbosity level (default 2)\n\
   -t N                  stop if no solution is found after N minutes (set\n\
                         to 0 for no time limit. Default 0)\n\
   -p PARAMETERS         set algorithm parameters. PARAMETERS is a comma\n\
                         separated string of options.\n"));
+	printf(_("\
+  -i PATH		set path to fitness modules\n\
+                        (Default %s)\n"), 
+  			HAVE_MODULE_PATH);
 
         printf("\n");
-        printf(_("Please report bugs to <tomaz.solc@siol.net>.\n"));
+        printf(_("Please report bugs to <tomaz.solc@tablix.org>.\n"));
         exit(0);
 }
 
@@ -213,7 +223,7 @@ int main(int argc, char *argv[])
         printf(_("TABLIX version %s, PGA general timetable solver\n"), VERSION);
         printf("Copyright (C) 2002-2006 Tomaz Solc\n");
 
-        while ((c=getopt(argc, argv, "hn:vo:rl:d:t:p:"))!=-1) {
+        while ((c=getopt(argc, argv, "hn:vo:rl:d:t:p:i:"))!=-1) {
                 switch (c) {
                         case 'v': print_copyright();
                         case 'h':
