@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: modsup.c,v 1.22 2006-03-22 20:26:07 avian Exp $ */
+/* $Id: modsup.c,v 1.26 2007-03-14 18:47:18 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -49,6 +49,11 @@ int mod_fitnessnum=0;
 /** @brief Linked list of all registered fitness functions. */
 fitnessfunc *mod_fitnessfunc=NULL;
 
+/** @brief Path to fitness and export modules. 
+ *
+ * Defaults to the location where modules were installed by "make install". */
+char *mod_modulepath=HAVE_MODULE_PATH;
+
 /** @brief Linked list of all registered precalc functions. */
 static precalcfunc *mod_precalc=NULL;
 
@@ -415,7 +420,7 @@ void table_fitness(table *tab)
 	ext *cur_ext;
 	slist *cur_slist;
 	fitnessfunc *cur;
-	int n,m,x,total;
+	int n,m,fitness,total;
 
 	assert(tab!=NULL);
 
@@ -444,14 +449,15 @@ void table_fitness(table *tab)
 		}
 		cur->chr[m]=NULL;
 
-		x=(*cur->func)(cur->chr, cur->req_ext, cur->req_slist);
+		fitness=(*cur->func)(cur->chr, cur->req_ext, cur->req_slist);
+		assert(fitness>=0);
 
-		x=x*cur->weight;
+		fitness=fitness*cur->weight;
 
-		tab->subtotals[n]=x;
-		total=total+x;
+		tab->subtotals[n]=fitness;
+		total=total+fitness;
 
-		if(x>0&&cur->man) tab->possible=0;
+		if(fitness>0&&cur->man) tab->possible=0;
 		
 		cur=cur->next;
 		n++;
@@ -644,16 +650,79 @@ modulelist *modulelist_new()
 	return(dest);
 }
 
+/** @brief Combines the base module name with module path and extension.
+ *
+ * If file name has no extension the default shared library extension
+ * for this system will be appended.
+ *
+ * If file name has a ".so" extension this extension will be replaced with
+ * the default shared library extension to remain backward compatible.
+ *
+ * @param name File name of the module
+ * @param prefix Module prefix (for example "export_" for export modules)
+ * @return Absolute path to the module with proper extension. Must be freed 
+ * after use. Returns NULL on memory allocation error. */
+char *module_filename_combine(char *prefix, char *name) 
+{
+	char *dest;
+	char *myname;
+
+	int namelen,totallen;
+
+	myname=strdup(name);
+	if(myname==NULL) return NULL;
+
+	namelen=strlen(myname);
+
+	if(namelen>=3) {
+		if(!strcmp(&myname[namelen-3], ".so")) {
+			info(_("Stripping '.so' extension from '%s' "
+						"module name."), myname);
+			info(_("Please use module names without extensions "
+					"in new problem descriptions."));
+
+			myname[namelen-3]='\0';
+		}
+	}
+
+	/* one byte for NULL termination, one byte for '/' */
+	totallen=	strlen(mod_modulepath)+
+			1+
+			strlen(prefix)+
+			strlen(myname)+
+			strlen(LTDL_SHLIB_EXT);
+
+	dest=malloc(sizeof(*dest)*(totallen+1));
+	if(dest==NULL) {
+		free(myname);
+		return(NULL);
+	}
+
+	strcpy(dest, mod_modulepath);
+	strcat(dest, "/");
+	strcat(dest, prefix);
+	strcat(dest, myname);
+	strcat(dest, LTDL_SHLIB_EXT);
+
+	assert(strlen(dest)==totallen);
+
+	free(myname);
+
+	return(dest);
+}
+
 /** @brief Loads a module. After the module is loaded, module_init() function
  * is called.
  *
- * @param name File name of the module (example: "timeplace.so").
+ * @sa module_filename_combine() 
+ *
+ * @param name File name of the module (example: "timeplace").
  * @param opt Linked list of options for this module.
  * @return Pointer to the module structure of the loaded module or NULL
  * on error. */
 module *module_load(char *name, moduleoption *opt) {
 	module *dest;
-	char pathname[1024];
+	char *pathname;
 	init_f init;
 	int n;
 
@@ -670,17 +739,29 @@ module *module_load(char *name, moduleoption *opt) {
 	dest=malloc(sizeof(*dest));
 	if(dest==NULL) return(NULL);
 
-	snprintf(pathname, 1024, "%s/%s", HAVE_MODULE_PATH, name);
+	pathname=module_filename_combine("", name);
+	if(pathname==NULL) {
+		free(dest);
+		error(_("Can't allocate memory"));
+		return(NULL);
+	}
+
 	debug(_("Loading module %s"), pathname);
 	dest->handle=dlopen(pathname, RTLD_NOW);
 	if(!dest->handle) {
+		error(_("Can't load module '%s'"), pathname);
 		msg_send("modsup", MSG_ERROR, dlerror());
 		free(dest);
 		return(NULL);
 	}
 
+	free(pathname);
+
 	init=dlsym(dest->handle,"module_init");
 	if(!init) {
+		error(_("Can't find module_init() in module '%s'"), name);
+		error(_("Are you trying to use modules from an "
+					"incompatible version of Tablix?"));
 		msg_send("modsup", MSG_ERROR, dlerror());
 		free(dest);
 		return(NULL);
