@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: output.c,v 1.25 2006-02-26 22:06:54 avian Exp $ */
+/* $Id: output.c,v 1.28 2006-08-29 14:32:24 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -68,7 +68,7 @@ along with this program; if not, write to the Free Software\n\
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA\n"));
         printf("\n");
 
-        printf("$Id: output.c,v 1.25 2006-02-26 22:06:54 avian Exp $\n");
+        printf("$Id: output.c,v 1.28 2006-08-29 14:32:24 avian Exp $\n");
         exit(0);
 }
 
@@ -86,7 +86,9 @@ void print_syntax()
                         the lowest fitness value is exported instead\n\
                         of any result stored in the XML file. If this option\n\
                         is used, the XML file does not need to contain a\n\
-                        solution."));
+                        solution.\n\
+  -i PATH		set path to fitness modules\n\
+                        (Default %s)\n"), mod_modulepath);
 
         printf("\n");
 	/*
@@ -96,7 +98,7 @@ Known output formats:\n\
   htmlcss               XHTML 1.1 using CSS and UTF-8 encoding (use this if\n\
                         some characters do not display correctly in browser)\n"));
         printf("\n"); */
-        printf(_("Please report bugs to <tomaz.solc@siol.net>.\n"));
+        printf(_("Please report bugs to <tomaz.solc@tablix.org>.\n"));
         exit(0);
 }
 
@@ -132,17 +134,33 @@ moduleoption *options_parse(char *optstr)
 export_f load_export(char *name)
 {
 	void *handle;
-	char pathname[1024];
+	char *pathname;
 	export_f dest;
 
-	snprintf(pathname, 1024, "%s/export_%s.so", HAVE_MODULE_PATH, name);
+	pathname=module_filename_combine("export_", name);
+	if(pathname==NULL) {
+		error(_("Can't allocate memory"));
+		return(NULL);
+	}
+
 	handle=dlopen(pathname, RTLD_NOW);
 
-	if(!handle) fatal(dlerror());
+	if(!handle) {
+		error(_("Can't load export module module '%s'"), pathname);
+		error("%s", dlerror());
+		return(NULL);
+	}
 
 	dest=dlsym(handle, "export_function");
+	if(dest==NULL) {
+		error(_("Can't find export_function() in module '%s'"), name);
+		error(_("Are you trying to use modules from an "
+					"incompatible version of Tablix?"));
+		error("%s", dlerror());
+		return(NULL);
+	}
 
-	if(dest==NULL) fatal(dlerror());
+	free(pathname);
 
 	return(dest);
 }
@@ -178,7 +196,7 @@ int main(int argc, char *argv[])
 
         /* *** Parse command line options               *** */
 
-        while ((c=getopt(argc, argv, "ho:vs:d:r:"))!=-1) {
+        while ((c=getopt(argc, argv, "ho:vs:d:r:i:"))!=-1) {
                 switch (c) {
                         case 'v': print_copyright();
                         case 'h':
@@ -193,6 +211,8 @@ int main(int argc, char *argv[])
 			case 'd': sscanf(optarg, "%d", &verbosity);
 				  verbosity+=100;
 				  break;
+			case 'i': mod_modulepath=optarg;
+				  break;
                 }
         }
 
@@ -232,6 +252,9 @@ int main(int argc, char *argv[])
 	}
 
 	export=load_export(argv[optind]);
+	if(export==NULL) {
+		fatal(_("Error loading export module"));
+	}
 
 	c=export(pop->tables[0], opt, output);
 	if(c!=0) {
