@@ -1,5 +1,5 @@
 /* TABLIX, PGA general timetable solver                              */
-/* Copyright (C) 2002-2005 Tomaz Solc                                      */
+/* Copyright (C) 2002-2006 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of the GNU General Public License as published by    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: params.c,v 1.3.4.5 2005/09/02 19:30:42 avian Exp $ */
+/* $Id: params.c,v 1.7 2006-02-04 14:16:12 avian Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -94,6 +94,20 @@ int par_localstep=4;
  * has no effect. */
 int par_pophint=25;
 
+/** @brief Size of fitness cache.
+ *
+ * This is the maximum number of timetable fitness values that will be held
+ * in the fitness cache.
+ *
+ * Larger values mean more cache search overhead but may improve cache hit/miss
+ * ratio. It is probably unwise to use caches larger than 32.
+ *
+ * In general fitness caching will reduce performance at the start of the
+ * genetic algorithm and improve it at the end. 
+ *
+ * Set to 0 to turn off caching. */
+int par_cachesize=16;
+
 /** @brief Map of parameter names to variables.
  *
  * Array must be terminated with an element containing NULL in both fields */
@@ -111,6 +125,7 @@ const static struct {
 			{ "localtresh", &par_localtresh },
 			{ "localstep", &par_localstep },
 			{ "pophint", &par_pophint },
+			{ "cachesize", &par_cachesize },
 			{ NULL, NULL } };
 
 /** @brief Parses a string and sets genetic parameters.
@@ -159,7 +174,7 @@ void par_print()
 {
 	int m;
 
-	debug(_("Genetic parameters:"));
+	debug(_("Genetic algorithm parameters:"));
 	m=0;
 	while(par_lookup[m].name!=NULL) {
 		debug(_("%s=%d"), par_lookup[m].name, *par_lookup[m].value);
