@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: xmlsup.c,v 1.34 2006-03-22 20:25:39 avian Exp $ */
+/* $Id: xmlsup.c,v 1.36 2007-01-14 19:10:06 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -201,6 +201,7 @@ static resource *parser_event_get_res(xmlNodePtr cur, resourcetype *restype)
 	xmlChar *type, *name;
 	
 	assert(restype!=NULL);
+	assert(cur!=NULL);
 
 	res=NULL;
 	
@@ -421,9 +422,9 @@ static void parser_events_restrictions(xmlNodePtr cur)
 
 /** @brief Parse a single event.
  *
- * @param start Pointer to the \<event\> node.
+ * @param event Pointer to the \<event\> node.
  * @param tuple Pointer to the tuple info struct for this event. */
-static void parser_event(xmlNodePtr start, tupleinfo *tuple)
+static void parser_event(xmlNodePtr event, tupleinfo *tuple)
 {
 	resource *res;
 	resourcetype *restype;
@@ -433,8 +434,9 @@ static void parser_event(xmlNodePtr start, tupleinfo *tuple)
 	xmlNodePtr cur;
 
 	assert(tuple!=NULL);
+	assert(event!=NULL);
 
-	cur=start;
+	cur=event->children;
 	while(cur!=NULL) {
 		if(!xmlStrcmp(cur->name, XMLCHAR "resource")) {
 			type=parser_getprop_str(cur, XMLCHAR "type");
@@ -449,11 +451,11 @@ static void parser_event(xmlNodePtr start, tupleinfo *tuple)
 	for(n=0;n<dat_typenum;n++) {
 		restype=&dat_restype[n];
 
-		res=parser_event_get_res(start->parent,restype);
+		res=parser_event_get_res(event, restype);
 		if(res==NULL&&(!restype->var)) {
 			fatal(_("Definition of event '%s' is missing constant "
 				"resource type '%s' (line %d)"), tuple->name, 
-				restype->type, xmlGetLineNo(start));
+				restype->type, xmlGetLineNo(event));
 		}
 
 		if(res!=NULL) tuple_set(tuple, res);
@@ -483,7 +485,7 @@ static void parser_events(xmlNodePtr cur)
 					fatal(_("Can't allocate memory"));
 				}
 
-				parser_event(cur->children, dest);
+				parser_event(cur, dest);
 			}
 
 			parser_newprop_int(cur, XMLCHAR "tupleid", 
@@ -670,7 +672,8 @@ static void parser_resource(xmlNodePtr cur, resourcetype *restype)
 					parser_newprop_int(cur, 
 							XMLCHAR "resid-from", 
 							dest->resid);
-				} else if(n==to) {
+				} 
+				if(n==to) {
 					parser_newprop_int(cur, 
 							XMLCHAR "resid-to", 
 							dest->resid);
